# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import

from ._backup_usage_summaries_crr_operations import BackupUsageSummariesCRROperations  # type: ignore
from ._aad_properties_operations import AadPropertiesOperations  # type: ignore
from ._cross_region_restore_operations import CrossRegionRestoreOperations  # type: ignore
from ._backup_crr_job_details_operations import BackupCrrJobDetailsOperations  # type: ignore
from ._backup_crr_jobs_operations import BackupCrrJobsOperations  # type: ignore
from ._crr_operation_results_operations import CrrOperationResultsOperations  # type: ignore
from ._crr_operation_status_operations import CrrOperationStatusOperations  # type: ignore
from ._recovery_points_operations import RecoveryPointsOperations  # type: ignore
from ._backup_resource_storage_configs_operations import BackupResourceStorageConfigsOperations  # type: ignore
from ._recovery_points_crr_operations import RecoveryPointsCrrOperations  # type: ignore
from ._backup_protected_items_crr_operations import BackupProtectedItemsCrrOperations  # type: ignore

from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "BackupUsageSummariesCRROperations",
    "AadPropertiesOperations",
    "CrossRegionRestoreOperations",
    "BackupCrrJobDetailsOperations",
    "BackupCrrJobsOperations",
    "CrrOperationResultsOperations",
    "CrrOperationStatusOperations",
    "RecoveryPointsOperations",
    "BackupResourceStorageConfigsOperations",
    "RecoveryPointsCrrOperations",
    "BackupProtectedItemsCrrOperations",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
