# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import


from ._models_py3 import (  # type: ignore
    AADProperties,
    AADPropertiesResource,
    AzureFileShareRecoveryPoint,
    AzureFileShareRestoreRequest,
    AzureFileshareProtectedItem,
    AzureFileshareProtectedItemExtendedInfo,
    AzureIaaSClassicComputeVMProtectedItem,
    AzureIaaSComputeVMProtectedItem,
    AzureIaaSVMErrorInfo,
    AzureIaaSVMHealthDetails,
    AzureIaaSVMJob,
    AzureIaaSVMJobExtendedInfo,
    AzureIaaSVMJobTaskDetails,
    AzureIaaSVMProtectedItem,
    AzureIaaSVMProtectedItemExtendedInfo,
    AzureSqlProtectedItem,
    AzureSqlProtectedItemExtendedInfo,
    AzureStorageErrorInfo,
    AzureStorageJob,
    AzureStorageJobExtendedInfo,
    AzureStorageJobTaskDetails,
    AzureVmWorkloadProtectedItem,
    AzureVmWorkloadProtectedItemExtendedInfo,
    AzureVmWorkloadSAPAseDatabaseProtectedItem,
    AzureVmWorkloadSAPHanaDatabaseProtectedItem,
    AzureVmWorkloadSQLDatabaseProtectedItem,
    AzureWorkloadErrorInfo,
    AzureWorkloadJob,
    AzureWorkloadJobExtendedInfo,
    AzureWorkloadJobTaskDetails,
    AzureWorkloadPointInTimeRecoveryPoint,
    AzureWorkloadPointInTimeRestoreRequest,
    AzureWorkloadRecoveryPoint,
    AzureWorkloadRestoreRequest,
    AzureWorkloadSAPHanaPointInTimeRecoveryPoint,
    AzureWorkloadSAPHanaPointInTimeRestoreRequest,
    AzureWorkloadSAPHanaRecoveryPoint,
    AzureWorkloadSAPHanaRestoreRequest,
    AzureWorkloadSQLPointInTimeRecoveryPoint,
    AzureWorkloadSQLPointInTimeRestoreRequest,
    AzureWorkloadSQLRecoveryPoint,
    AzureWorkloadSQLRecoveryPointExtendedInfo,
    AzureWorkloadSQLRestoreRequest,
    BEKDetails,
    BMSAADPropertiesQueryObject,
    BMSBackupSummariesQueryObject,
    BMSRPQueryObject,
    BackupManagementUsage,
    BackupManagementUsageList,
    BackupResourceConfig,
    BackupResourceConfigResource,
    ClientScriptForConnect,
    CrossRegionRestoreRequest,
    CrossRegionRestoreRequestResource,
    CrrAccessToken,
    CrrAccessTokenResource,
    CrrJobRequest,
    CrrJobRequestResource,
    DPMProtectedItem,
    DPMProtectedItemExtendedInfo,
    DiskExclusionProperties,
    DiskInformation,
    DpmErrorInfo,
    DpmJob,
    DpmJobExtendedInfo,
    DpmJobTaskDetails,
    EncryptionDetails,
    ErrorAdditionalInfo,
    ErrorDetail,
    ExtendedProperties,
    GenericProtectedItem,
    GenericRecoveryPoint,
    IaasVMRecoveryPoint,
    IaasVMRestoreRequest,
    IdentityBasedRestoreDetails,
    IdentityInfo,
    InstantItemRecoveryTarget,
    Job,
    JobQueryObject,
    JobResource,
    JobResourceList,
    KEKDetails,
    KPIResourceHealthDetails,
    KeyAndSecretDetails,
    MabErrorInfo,
    MabFileFolderProtectedItem,
    MabFileFolderProtectedItemExtendedInfo,
    MabJob,
    MabJobExtendedInfo,
    MabJobTaskDetails,
    NameInfo,
    NewErrorResponse,
    NewErrorResponseError,
    OperationStatus,
    OperationStatusError,
    OperationStatusExtendedInfo,
    OperationStatusJobExtendedInfo,
    OperationStatusJobsExtendedInfo,
    OperationStatusProvisionILRExtendedInfo,
    OperationStatusRecoveryPointExtendedInfo,
    PointInTimeRange,
    ProtectedItem,
    ProtectedItemQueryObject,
    ProtectedItemResource,
    ProtectedItemResourceList,
    RecoveryPoint,
    RecoveryPointDiskConfiguration,
    RecoveryPointMoveReadinessInfo,
    RecoveryPointResource,
    RecoveryPointResourceList,
    RecoveryPointTierInformation,
    Resource,
    ResourceHealthDetails,
    ResourceList,
    RestoreFileSpecs,
    RestoreRequest,
    SQLDataDirectory,
    SQLDataDirectoryMapping,
    TargetAFSRestoreInfo,
    TargetRestoreInfo,
    WorkloadCrrAccessToken,
)

from ._recovery_services_backup_passive_client_enums import (  # type: ignore
    BackupManagementType,
    CopyOptions,
    CreateMode,
    DataSourceType,
    HealthState,
    HealthStatus,
    JobOperationType,
    JobStatus,
    JobSupportedAction,
    LastBackupStatus,
    MabServerType,
    OperationStatusValues,
    OverwriteOptions,
    ProtectedItemHealthStatus,
    ProtectedItemState,
    ProtectionState,
    RecoveryMode,
    RecoveryPointTierStatus,
    RecoveryPointTierType,
    RecoveryType,
    ResourceHealthStatus,
    RestorePointQueryType,
    RestorePointType,
    RestoreRequestType,
    SQLDataDirectoryType,
    StorageType,
    StorageTypeState,
    Type,
    UsagesUnit,
    WorkloadType,
)
from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AADProperties",
    "AADPropertiesResource",
    "AzureFileShareRecoveryPoint",
    "AzureFileShareRestoreRequest",
    "AzureFileshareProtectedItem",
    "AzureFileshareProtectedItemExtendedInfo",
    "AzureIaaSClassicComputeVMProtectedItem",
    "AzureIaaSComputeVMProtectedItem",
    "AzureIaaSVMErrorInfo",
    "AzureIaaSVMHealthDetails",
    "AzureIaaSVMJob",
    "AzureIaaSVMJobExtendedInfo",
    "AzureIaaSVMJobTaskDetails",
    "AzureIaaSVMProtectedItem",
    "AzureIaaSVMProtectedItemExtendedInfo",
    "AzureSqlProtectedItem",
    "AzureSqlProtectedItemExtendedInfo",
    "AzureStorageErrorInfo",
    "AzureStorageJob",
    "AzureStorageJobExtendedInfo",
    "AzureStorageJobTaskDetails",
    "AzureVmWorkloadProtectedItem",
    "AzureVmWorkloadProtectedItemExtendedInfo",
    "AzureVmWorkloadSAPAseDatabaseProtectedItem",
    "AzureVmWorkloadSAPHanaDatabaseProtectedItem",
    "AzureVmWorkloadSQLDatabaseProtectedItem",
    "AzureWorkloadErrorInfo",
    "AzureWorkloadJob",
    "AzureWorkloadJobExtendedInfo",
    "AzureWorkloadJobTaskDetails",
    "AzureWorkloadPointInTimeRecoveryPoint",
    "AzureWorkloadPointInTimeRestoreRequest",
    "AzureWorkloadRecoveryPoint",
    "AzureWorkloadRestoreRequest",
    "AzureWorkloadSAPHanaPointInTimeRecoveryPoint",
    "AzureWorkloadSAPHanaPointInTimeRestoreRequest",
    "AzureWorkloadSAPHanaRecoveryPoint",
    "AzureWorkloadSAPHanaRestoreRequest",
    "AzureWorkloadSQLPointInTimeRecoveryPoint",
    "AzureWorkloadSQLPointInTimeRestoreRequest",
    "AzureWorkloadSQLRecoveryPoint",
    "AzureWorkloadSQLRecoveryPointExtendedInfo",
    "AzureWorkloadSQLRestoreRequest",
    "BEKDetails",
    "BMSAADPropertiesQueryObject",
    "BMSBackupSummariesQueryObject",
    "BMSRPQueryObject",
    "BackupManagementUsage",
    "BackupManagementUsageList",
    "BackupResourceConfig",
    "BackupResourceConfigResource",
    "ClientScriptForConnect",
    "CrossRegionRestoreRequest",
    "CrossRegionRestoreRequestResource",
    "CrrAccessToken",
    "CrrAccessTokenResource",
    "CrrJobRequest",
    "CrrJobRequestResource",
    "DPMProtectedItem",
    "DPMProtectedItemExtendedInfo",
    "DiskExclusionProperties",
    "DiskInformation",
    "DpmErrorInfo",
    "DpmJob",
    "DpmJobExtendedInfo",
    "DpmJobTaskDetails",
    "EncryptionDetails",
    "ErrorAdditionalInfo",
    "ErrorDetail",
    "ExtendedProperties",
    "GenericProtectedItem",
    "GenericRecoveryPoint",
    "IaasVMRecoveryPoint",
    "IaasVMRestoreRequest",
    "IdentityBasedRestoreDetails",
    "IdentityInfo",
    "InstantItemRecoveryTarget",
    "Job",
    "JobQueryObject",
    "JobResource",
    "JobResourceList",
    "KEKDetails",
    "KPIResourceHealthDetails",
    "KeyAndSecretDetails",
    "MabErrorInfo",
    "MabFileFolderProtectedItem",
    "MabFileFolderProtectedItemExtendedInfo",
    "MabJob",
    "MabJobExtendedInfo",
    "MabJobTaskDetails",
    "NameInfo",
    "NewErrorResponse",
    "NewErrorResponseError",
    "OperationStatus",
    "OperationStatusError",
    "OperationStatusExtendedInfo",
    "OperationStatusJobExtendedInfo",
    "OperationStatusJobsExtendedInfo",
    "OperationStatusProvisionILRExtendedInfo",
    "OperationStatusRecoveryPointExtendedInfo",
    "PointInTimeRange",
    "ProtectedItem",
    "ProtectedItemQueryObject",
    "ProtectedItemResource",
    "ProtectedItemResourceList",
    "RecoveryPoint",
    "RecoveryPointDiskConfiguration",
    "RecoveryPointMoveReadinessInfo",
    "RecoveryPointResource",
    "RecoveryPointResourceList",
    "RecoveryPointTierInformation",
    "Resource",
    "ResourceHealthDetails",
    "ResourceList",
    "RestoreFileSpecs",
    "RestoreRequest",
    "SQLDataDirectory",
    "SQLDataDirectoryMapping",
    "TargetAFSRestoreInfo",
    "TargetRestoreInfo",
    "WorkloadCrrAccessToken",
    "BackupManagementType",
    "CopyOptions",
    "CreateMode",
    "DataSourceType",
    "HealthState",
    "HealthStatus",
    "JobOperationType",
    "JobStatus",
    "JobSupportedAction",
    "LastBackupStatus",
    "MabServerType",
    "OperationStatusValues",
    "OverwriteOptions",
    "ProtectedItemHealthStatus",
    "ProtectedItemState",
    "ProtectionState",
    "RecoveryMode",
    "RecoveryPointTierStatus",
    "RecoveryPointTierType",
    "RecoveryType",
    "ResourceHealthStatus",
    "RestorePointQueryType",
    "RestorePointType",
    "RestoreRequestType",
    "SQLDataDirectoryType",
    "StorageType",
    "StorageTypeState",
    "Type",
    "UsagesUnit",
    "WorkloadType",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
